#
# Configuration file for using the xslt library
#
XSLT_LIBDIR="-L/usr/i686-w64-mingw32/sys-root/mingw/lib"
XSLT_LIBS="-lxslt  -L/usr/i686-w64-mingw32/sys-root/mingw/lib -lxml2 -lz -llzma -liconv -lws2_32  "
XSLT_INCLUDEDIR="-I/usr/i686-w64-mingw32/sys-root/mingw/include"
MODULE_VERSION="xslt-1.1.29"
